## Boip Animator
Boip Animator is a python library for creating text-based (ascii) animations.<br>
Boip is a simple and useful library for creating console animations.<br>

## Requirements
**python: 3.8+**<br>
**playsound: 1.2.2+**<br>
how to download playound?<br>
open cmd and type `pip install playsound`
